==> kirui-0.1.8.tar.gz: kirui-0.1.8/kirui_devserver/kirui/components/panel/ajax.js <==
import { Component } from "/kirui/core/component";
import { registry } from "/kirui/core/registry";
import {createRef, h, render,hydrate} from 'preact';
import $ from "jquery";


class KrAjaxPanel extends Component {
    constructor(props) {
        super(props);
        props.ref = createRef();
        this.handleStateChange = this.handleStateChange.bind(this);
        document.addEventListener('state-change', this.handleStateChange);
    }

    refreshContent() {
        let e = new CustomEvent('AjaxLoading', {'bubbles': true, 'detail': {'loading': true}});
        this.base.dispatchEvent(e);

        $.post({
            url: this.props.contentUrl || window.location.href,
            data: $.param(this.state, true),
            statusCode: {
                340: function (resp) {
                    window.location.replace(resp.getResponseHeader('location'));
                    console.log(resp.getResponseHeader('location'));
                }
            }
        }).done((resp) => {
            let dom = resp;
            this.dataToCreateElement([dom]);
            this.props.children = dom[2];
            this.forceUpdate();
            let e = new CustomEvent('AjaxLoading', {'bubbles': true, 'detail': {'loading': false}});
            this.base.dispatchEvent(e);
        }).fail((resp) => {
            if (resp.status === 403) {
                let dom = resp.responseJSON;
                this.dataToCreateElement([dom]);
                this.props.children = dom[2];
                this.forceUpdate();
                let e = new CustomEvent('AjaxLoading', {'bubbles': true, 'detail': {'loading': false}});
                this.base.dispatchEvent(e);
            }
        });
    }

    doRender() {
        return <kr-ajax-panel {...this.props} onStateChange={this.handleStateChange} onReloadContent={this.handleStateChange}>{this.props.children}</kr-ajax-panel>;
    }

    handleStateChange(ev) {
        let data = this.state;
        $.extend(data, ev.detail.data);
        this.setState(data);
        if (ev.detail.forceUpdate === true) {
            this.refreshContent();
        }
    }

    componentDidMount() {
        /* this.base. */
        // window.addEventListener('state-change', this.handleStateChange);
    }
}

registry.register('kr-ajax-panel', KrAjaxPanel);

export { KrAjaxPanel }

==> kirui-0.3.1.tar.gz: kirui-0.3.1/kirui_devserver/kirui/components/panel/ajax.js <==
import { Component } from "/kirui/core/component";
import { registry } from "/kirui/core/registry";
import {createRef, h, render} from 'preact';
import { evaluate } from '/kirui/core/element';
import $ from "jquery";


class KrAjaxPanel extends Component {
    constructor(props) {
        super(props);
        props.ref = createRef();
        this.handleStateChange = this.handleStateChange.bind(this);
        this.refreshContent = this.refreshContent.bind(this);
        document.addEventListener('state-change', this.handleStateChange);
        document.addEventListener('ReloadContent', this.refreshContent);
    }

    refreshContent(extra_data) {
        let e = new CustomEvent('AjaxLoading', {'bubbles': true, 'detail': {'loading': true}});
        this.base.dispatchEvent(e);

        let data = this.state;
        if ((extra_data !== undefined) && (extra_data !== null)) {
            data[extra_data] = '';
        }
        $.post({
            url: this.props.contentUrl || window.location.href,
            data: $.param(data, true),
            statusCode: {
                340: function (resp) {
                    window.location.replace(resp.getResponseHeader('location'));
                }
            }
        }).done((resp) => {
            let dom = evaluate(resp);
            this.props.children = dom.props.children;
            this.forceUpdate();
            let e = new CustomEvent('AjaxLoading', {'bubbles': true, 'detail': {'loading': false}});
            this.base.dispatchEvent(e);
        }).fail((resp) => {
            if (resp.status === 403) {
                let d = evaluate(resp.responseText);
                this.props.children = d.props.children;
                this.forceUpdate();
                let e = new CustomEvent('AjaxLoading', {'bubbles': true, 'detail': {'loading': false}});
                this.base.dispatchEvent(e);
            }
        });
    }

    doRender() {
        return <kr-ajax-panel {...this.props} onStateChange={this.handleStateChange}>{this.props.children}</kr-ajax-panel>;
    }

    handleStateChange(ev) {
        let data = this.state;
        $.extend(data, ev.detail.data);
        this.setState(data);

        if (ev.detail.forceUpdate === true) {
            this.refreshContent(ev.detail.src);
        }
    }

    componentDidMount() {
        /* this.base. */
        // window.addEventListener('state-change', this.handleStateChange);
    }
}

registry.register('kr-ajax-panel', KrAjaxPanel);

export { KrAjaxPanel }
